aztec-nr - noir_aztec::messages::logs::note

Function encode_and_encrypt_note

pub fn encode_and_encrypt_note<Note>(
    context: &mut PrivateContext,
    recipient: AztecAddress,
) -> fn[(&mut PrivateContext, AztecAddress)](NoteEmission<Note>)
where Note: NoteType, Note: Packable

Sends an encrypted message to recipient with the content of the note, which they will discover when processing private logs.