Function encode_and_encrypt_note_unconstrained
pub fn encode_and_encrypt_note_unconstrained<Note>(
context: &mut PrivateContext,
recipient: AztecAddress,
) -> fn[(&mut PrivateContext, AztecAddress)](NoteEmission<Note>)
pub fn encode_and_encrypt_note_unconstrained<Note>(
context: &mut PrivateContext,
recipient: AztecAddress,
) -> fn[(&mut PrivateContext, AztecAddress)](NoteEmission<Note>)
Same as
encode_and_encrypt_note, except encryption is unconstrained. This means that the sender is free to make the log contents be whatever they wish, potentially resulting in scenarios in which the recipient is unable to decrypt and process the payload, leading to the note being lost.Only use this function in scenarios where the recipient not receiving the note is an acceptable outcome.